Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(18)

Unified Diff: pkg/analyzer/lib/source/analysis_options_provider.dart

Issue 1412213003: Register .analysis_options files for analysis. (Closed) Base URL: git@github.com:dart-lang/sdk.git@master
Patch Set: Created 5 years, 2 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « pkg/analysis_server/lib/src/plugin/server_plugin.dart ('k') | pkg/analyzer/lib/src/generated/engine.dart » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: pkg/analyzer/lib/source/analysis_options_provider.dart
diff --git a/pkg/analyzer/lib/source/analysis_options_provider.dart b/pkg/analyzer/lib/source/analysis_options_provider.dart
index 1c05375fc1f32483327cc97d59ccfca9a49dc4ba..aeac0531ecd0900f04baa9823592b8be49697002 100644
--- a/pkg/analyzer/lib/source/analysis_options_provider.dart
+++ b/pkg/analyzer/lib/source/analysis_options_provider.dart
@@ -5,18 +5,16 @@
library source.analysis_options_provider;
import 'package:analyzer/file_system/file_system.dart';
+import 'package:analyzer/src/generated/engine.dart';
import 'package:yaml/yaml.dart';
/// Provide the options found in the `.analysis_options` file.
class AnalysisOptionsProvider {
- /// The name of the analysis options source file.
- static const String ANALYSIS_OPTIONS_NAME = '.analysis_options';
-
- /// Provide the options found in [root]/[ANALYSIS_OPTIONS_NAME].
+ /// Provide the options found in [root]/[ANALYSIS_OPTIONS_FILE].
/// Return an empty options map if the file does not exist.
Map<String, YamlNode> getOptions(Folder root) {
- var optionsSource =
- _readAnalysisOptionsFile(root.getChild(ANALYSIS_OPTIONS_NAME));
+ var optionsSource = _readAnalysisOptionsFile(
+ root.getChild(AnalysisEngine.ANALYSIS_OPTIONS_FILE));
return getOptionsFromString(optionsSource);
}
« no previous file with comments | « pkg/analysis_server/lib/src/plugin/server_plugin.dart ('k') | pkg/analyzer/lib/src/generated/engine.dart » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698